Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2018-07-15 00:55:20 +0300
committerCampbell Barton <ideasman42@gmail.com>2018-07-15 00:55:54 +0300
commit89299f66207bd278e37e9e55ade87e8989b0de3d (patch)
treed0287dd0aa7ceb3d5a7f9cb22018c0b41e76790b /release/scripts/templates_py/gizmo_simple.py
parent5ebebcfbfff4c218ab4101ee7f6a66617ee9b01f (diff)
WM: rename manipulator to gizmo in Python API
Diffstat (limited to 'release/scripts/templates_py/gizmo_simple.py')
-rw-r--r--release/scripts/templates_py/gizmo_simple.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/release/scripts/templates_py/gizmo_simple.py b/release/scripts/templates_py/gizmo_simple.py
index cb10a8b94bb..0fd1e0b386b 100644
--- a/release/scripts/templates_py/gizmo_simple.py
+++ b/release/scripts/templates_py/gizmo_simple.py
@@ -1,16 +1,16 @@
# Example of a group that edits a single property
# using the predefined manipulator arrow.
#
# Usage: Select a light in the 3D view and drag the arrow at it's rear
# to change it's energy value.
#
import bpy
from bpy.types import (
- ManipulatorGroup,
+ GizmoGroup,
)
-class MyLightWidgetGroup(ManipulatorGroup):
+class MyLightWidgetGroup(GizmoGroup):
bl_idname = "OBJECT_WGT_light_test"
bl_label = "Test Light Widget"
bl_space_type = 'VIEW_3D'
@@ -23,9 +23,9 @@ class MyLightWidgetGroup(ManipulatorGroup):
return (ob and ob.type == 'LIGHT')
def setup(self, context):
# Arrow manipulator has one 'offset' property we can assign to the light energy.
ob = context.object
- mpr = self.manipulators.new("MANIPULATOR_WT_arrow_3d")
+ mpr = self.gizmos.new("GIZMO_WT_arrow_3d")
mpr.target_set_prop("offset", ob.data, "energy")
mpr.matrix_basis = ob.matrix_world.normalized()
mpr.draw_style = 'BOX'
@@ -1,16 +1,16 @@
# Example of a group that edits a single property
-# using the predefined manipulator arrow.
+# using the predefined gizmo arrow.
#
# Usage: Select a light in the 3D view and drag the arrow at it's rear
@@ -23,9 +23,9 @@ class MyLightWidgetGroup(ManipulatorGroup):
return (ob and ob.type == 'LIGHT')
def setup(self, context):
- # Arrow manipulator has one 'offset' property we can assign to the light energy.
+ # Arrow gizmo has one 'offset' property we can assign to the light energy.
ob = context.object